@@ -6,8 +6,6 @@ test_that("simple working example", {
   # id 4 - in cohort for 20 days, exits the database after 25
 
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     drug_exposure = dplyr::tibble(
       drug_exposure_id = 1:4,
       person_id = c(1, 2, 3, 4),
@@ -30,7 +28,8 @@ test_that("simple working example", {
       observation_period_end_date = as.Date(c("2000-01-25", "2002-01-15", "2010-01-25", "2011-01-25")),
       period_type_concept_id = 0
     )
-  )
+  ) |>
+    copyCdm()
 
   ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered()
@@ -87,7 +86,7 @@ test_that("simple working example", {
     ) |>
     dplyr::pull("estimate_value") == "0.00")
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("multiple cohort entries", {
@@ -96,8 +95,6 @@ test_that("multiple cohort entries", {
   # id 2 - in cohort for 15 days, exits the database after 25
 
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     drug_exposure = dplyr::tibble(
       drug_exposure_id = 1:3,
       person_id = c(1, 1, 2),
@@ -120,7 +117,8 @@ test_that("multiple cohort entries", {
       observation_period_end_date = as.Date(c("2000-01-20", "2010-01-25")),
       period_type_concept_id = 0
     )
-  )
+  ) |>
+    copyCdm()
 
   ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered(followUpDays = 25)
@@ -163,7 +161,7 @@ test_that("multiple cohort entries", {
     ) |>
     dplyr::pull("estimate_value") == "0.00")
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("multiple cohorts", {
@@ -174,8 +172,6 @@ test_that("multiple cohorts", {
   # id 3 - in cohort 1 for 20 days, exits the database after 25
   # id 4 - in cohort 2 for 25 days, exits the database after 30
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     drug_exposure = dplyr::tibble(
       drug_exposure_id = 1:4,
       person_id = c(1, 2, 3, 4),
@@ -198,7 +194,8 @@ test_that("multiple cohorts", {
       observation_period_end_date = as.Date(c("2000-01-25", "2002-01-15", "2010-01-25", "2011-01-30")),
       period_type_concept_id = 0
     )
-  )
+  ) |>
+    copyCdm()
 
   ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered()
@@ -270,7 +267,7 @@ test_that("multiple cohorts", {
   expect_no_error(cdm$dus_cohort |>
     summariseProportionOfPatientsCovered(cohortId = 1))
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("stratification", {
@@ -282,8 +279,6 @@ test_that("stratification", {
   # id 4 - in cohort for 20 days, exits the database after 25
 
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     dus_cohort = dplyr::tibble(
       cohort_definition_id = 1,
       subject_id = c(1, 1, 2, 3, 4),
@@ -308,6 +303,7 @@ test_that("stratification", {
         "group_a", "group_b"
       )
     )
+  cdm <- copyCdm(cdm = cdm)
 
   ppc_no_strata <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered(followUpDays = 30)
@@ -492,15 +488,13 @@ test_that("stratification", {
   ppc_g1_gb <- ppc |> dplyr::filter(strata_level == "group_1 &&& group_b")
   expect_true(nrow(ppc_g1_gb) == 0)
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("expected errors", {
   skip_on_cran()
 
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     dus_cohort = dplyr::tibble(
       cohort_definition_id = c(1, 1, 1, 2),
       subject_id = c(1, 2, 3, 4),
@@ -514,7 +508,8 @@ test_that("expected errors", {
       observation_period_end_date = as.Date(c("2000-01-25", "2002-01-15", "2010-01-25", "2011-01-30")),
       period_type_concept_id = 0
     )
-  )
+  ) |>
+    copyCdm()
 
   ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered()
@@ -545,15 +540,13 @@ test_that("expected errors", {
   expect_error(ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered(strata = list("not_a_column")))
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("suppression", {
   skip_on_cran()
 
   cdm <- mockDrugUtilisation(
-    con = connection(),
-    writeSchema = schema(),
     drug_exposure = dplyr::tibble(
       drug_exposure_id = 1:4,
       person_id = c(1, 2, 3, 4),
@@ -576,7 +569,8 @@ test_that("suppression", {
       observation_period_end_date = as.Date(c("2000-01-25", "2002-01-15", "2010-01-25", "2011-01-25")),
       period_type_concept_id = 0
     )
-  )
+  ) |>
+    copyCdm()
 
   ppc <- cdm$dus_cohort |>
     summariseProportionOfPatientsCovered()
@@ -598,5 +592,5 @@ test_that("suppression", {
       dplyr::pull("estimate_value") == "-"
   )
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
